---
# SPDX-FileCopyrightText: 2024 Nicco Kunzmann and Open Web Calendar Contributors <https://open-web-calendar.quelltext.eu/>
#
# SPDX-License-Identifier: CC-BY-SA-4.0

comments: true
---

# Showcase

The Open Web Calender is used internationally and in a variety of different places.
This page is for community contributions to show how they use the Open Web Calendar.

> Please share they way you use the Open Web Calendar here and inspire others!

- [Events on a High Screen](events-high-screen)
- [Info Screen with Agenda](agenda-info-screen)
- [Self-hosting & Gancio Integration](self-host-gancio)
